pub fn load_file_bytes(
file: &DecryptionInputFile,
) -> Result<Vec<u8>, WorkflowError>Expand description
Reads the complete raw bytes of an encrypted input file. Parsing happens in the workflow, per format version.
pub fn load_file_bytes(
file: &DecryptionInputFile,
) -> Result<Vec<u8>, WorkflowError>Reads the complete raw bytes of an encrypted input file. Parsing happens in the workflow, per format version.