pub fn generate_nonce_prefix() -> Result<[u8; 16], WorkflowError>Expand description
Random prefix for the v3 content stream nonces (the per-chunk counter and final flag fill the remaining nonce bytes).
pub fn generate_nonce_prefix() -> Result<[u8; 16], WorkflowError>Random prefix for the v3 content stream nonces (the per-chunk counter and final flag fill the remaining nonce bytes).