pub fn display_file_info_list_json(info_list: &FileInfoList)Expand description
Prints the listing as a JSON array on stdout, for scripting.
original_filename is null when names were not requested or a name
could not be decrypted.
pub fn display_file_info_list_json(info_list: &FileInfoList)Prints the listing as a JSON array on stdout, for scripting.
original_filename is null when names were not requested or a name
could not be decrypted.