pub fn load_file_header_bytes(
file: &ShadowFile,
) -> Result<SecureBytes, WorkflowError>Expand description
Reads the complete raw header bytes of a shadow file. Deserialization happens in the workflow, per format version.
pub fn load_file_header_bytes(
file: &ShadowFile,
) -> Result<SecureBytes, WorkflowError>Reads the complete raw header bytes of a shadow file. Deserialization happens in the workflow, per format version.